==> openshift-model-monitoring-4.13.0-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/RemoteWriteSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface RemoteWriteSpecFluent<A extends RemoteWriteSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildBasicAuth instead.
 * @return The buildable object.
 */
@Deprecated public BasicAuth getBasicAuth();
    public BasicAuth buildBasicAuth();
    public A withBasicAuth(BasicAuth basicAuth);
    public Boolean hasBasicAuth();
    public RemoteWriteSpecFluent.BasicAuthNested<A> withNewBasicAuth();
    public RemoteWriteSpecFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuth item);
    public RemoteWriteSpecFluent.BasicAuthNested<A> editBasicAuth();
    public RemoteWriteSpecFluent.BasicAuthNested<A> editOrNewBasicAuth();
    public RemoteWriteSpecFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuth item);
    public String getBearerToken();
    public A withBearerToken(String bearerToken);
    public Boolean hasBearerToken();
    public A withNewBearerToken(String arg1);
    public A withNewBearerToken(StringBuilder arg1);
    public A withNewBearerToken(StringBuffer arg1);
    public String getBearerTokenFile();
    public A withBearerTokenFile(String bearerTokenFile);
    public Boolean hasBearerTokenFile();
    public A withNewBearerTokenFile(String arg1);
    public A withNewBearerTokenFile(StringBuilder arg1);
    public A withNewBearerTokenFile(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getProxyUrl();
    public A withProxyUrl(String proxyUrl);
    public Boolean hasProxyUrl();
    public A withNewProxyUrl(String arg1);
    public A withNewProxyUrl(StringBuilder arg1);
    public A withNewProxyUrl(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildQueueConfig instead.
 * @return The buildable object.
 */
@Deprecated public QueueConfig getQueueConfig();
    public QueueConfig buildQueueConfig();
    public A withQueueConfig(QueueConfig queueConfig);
    public Boolean hasQueueConfig();
    public RemoteWriteSpecFluent.QueueConfigNested<A> withNewQueueConfig();
    public RemoteWriteSpecFluent.QueueConfigNested<A> withNewQueueConfigLike(QueueConfig item);
    public RemoteWriteSpecFluent.QueueConfigNested<A> editQueueConfig();
    public RemoteWriteSpecFluent.QueueConfigNested<A> editOrNewQueueConfig();
    public RemoteWriteSpecFluent.QueueConfigNested<A> editOrNewQueueConfigLike(QueueConfig item);
    public String getRemoteTimeout();
    public A withRemoteTimeout(String remoteTimeout);
    public Boolean hasRemoteTimeout();
    public A withNewRemoteTimeout(String arg1);
    public A withNewRemoteTimeout(StringBuilder arg1);
    public A withNewRemoteTimeout(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildTlsConfig instead.
 * @return The buildable object.
 */
@Deprecated public TLSConfig getTlsConfig();
    public TLSConfig buildTlsConfig();
    public A withTlsConfig(TLSConfig tlsConfig);
    public Boolean hasTlsConfig();
    public RemoteWriteSpecFluent.TlsConfigNested<A> withNewTlsConfig();
    public RemoteWriteSpecFluent.TlsConfigNested<A> withNewTlsConfigLike(TLSConfig item);
    public RemoteWriteSpecFluent.TlsConfigNested<A> editTlsConfig();
    public RemoteWriteSpecFluent.TlsConfigNested<A> editOrNewTlsConfig();
    public RemoteWriteSpecFluent.TlsConfigNested<A> editOrNewTlsConfigLike(TLSConfig item);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(String arg1);
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(StringBuffer arg1);
    public A addToWriteRelabelConfigs(int index,RelabelConfig item);
    public A setToWriteRelabelConfigs(int index,RelabelConfig item);
    public A addToWriteRelabelConfigs(RelabelConfig... items);
    public A addAllToWriteRelabelConfigs(Collection<RelabelConfig> items);
    public A removeFromWriteRelabelConfigs(RelabelConfig... items);
    public A removeAllFromWriteRelabelConfigs(Collection<RelabelConfig> items);
    public A removeMatchingFromWriteRelabelConfigs(io.fabric8.kubernetes.api.builder.Predicate<RelabelConfigBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildWriteRelabelConfigs instead.
 * @return The buildable object.
 */
@Deprecated public List<RelabelConfig> getWriteRelabelConfigs();
    public List<RelabelConfig> buildWriteRelabelConfigs();
    public RelabelConfig buildWriteRelabelConfig(int index);
    public RelabelConfig buildFirstWriteRelabelConfig();
    public RelabelConfig buildLastWriteRelabelConfig();
    public RelabelConfig buildMatchingWriteRelabelConfig(io.fabric8.kubernetes.api.builder.Predicate<RelabelConfigBuilder> predicate);
    public Boolean hasMatchingWriteRelabelConfig(io.fabric8.kubernetes.api.builder.Predicate<RelabelConfigBuilder> predicate);
    public A withWriteRelabelConfigs(List<RelabelConfig> writeRelabelConfigs);
    public A withWriteRelabelConfigs(RelabelConfig... writeRelabelConfigs);
    public Boolean hasWriteRelabelConfigs();
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> addNewWriteRelabelConfig();
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> addNewWriteRelabelConfigLike(RelabelConfig item);
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> setNewWriteRelabelConfigLike(int index,RelabelConfig item);
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editWriteRelabelConfig(int index);
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editFirstWriteRelabelConfig();
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editLastWriteRelabelConfig();
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editMatchingWriteRelabelConfig(io.fabric8.kubernetes.api.builder.Predicate<RelabelConfigBuilder> predicate);
    public interface BasicAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BasicAuthFluent<RemoteWriteSpecFluent.BasicAuthNested<N>> {

        public N and();
        public N endBasicAuth();    }


    public interface QueueConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,QueueConfigFluent<RemoteWriteSpecFluent.QueueConfigNested<N>> {

        public N and();
        public N endQueueConfig();    }


    public interface TlsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSConfigFluent<RemoteWriteSpecFluent.TlsConfigNested<N>> {

        public N and();
        public N endTlsConfig();    }


    public interface WriteRelabelConfigsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RelabelConfigFluent<RemoteWriteSpecFluent.WriteRelabelConfigsNested<N>> {

        public N and();
        public N endWriteRelabelConfig();    }


}

==> openshift-model-monitoring-5.2.1-sources.jar: annotations/io/fabric8/openshift/api/model/monitoring/v1/RemoteWriteSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface RemoteWriteSpecFluent<A extends RemoteWriteSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildBasicAuth instead.
 * @return The buildable object.
 */
@Deprecated public BasicAuth getBasicAuth();
    public BasicAuth buildBasicAuth();
    public A withBasicAuth(BasicAuth basicAuth);
    public Boolean hasBasicAuth();
    public RemoteWriteSpecFluent.BasicAuthNested<A> withNewBasicAuth();
    public RemoteWriteSpecFluent.BasicAuthNested<A> withNewBasicAuthLike(BasicAuth item);
    public RemoteWriteSpecFluent.BasicAuthNested<A> editBasicAuth();
    public RemoteWriteSpecFluent.BasicAuthNested<A> editOrNewBasicAuth();
    public RemoteWriteSpecFluent.BasicAuthNested<A> editOrNewBasicAuthLike(BasicAuth item);
    public String getBearerToken();
    public A withBearerToken(String bearerToken);
    public Boolean hasBearerToken();
    public A withNewBearerToken(String arg1);
    public A withNewBearerToken(StringBuilder arg1);
    public A withNewBearerToken(StringBuffer arg1);
    public String getBearerTokenFile();
    public A withBearerTokenFile(String bearerTokenFile);
    public Boolean hasBearerTokenFile();
    public A withNewBearerTokenFile(String arg1);
    public A withNewBearerTokenFile(StringBuilder arg1);
    public A withNewBearerTokenFile(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public String getProxyUrl();
    public A withProxyUrl(String proxyUrl);
    public Boolean hasProxyUrl();
    public A withNewProxyUrl(String arg1);
    public A withNewProxyUrl(StringBuilder arg1);
    public A withNewProxyUrl(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildQueueConfig instead.
 * @return The buildable object.
 */
@Deprecated public QueueConfig getQueueConfig();
    public QueueConfig buildQueueConfig();
    public A withQueueConfig(QueueConfig queueConfig);
    public Boolean hasQueueConfig();
    public RemoteWriteSpecFluent.QueueConfigNested<A> withNewQueueConfig();
    public RemoteWriteSpecFluent.QueueConfigNested<A> withNewQueueConfigLike(QueueConfig item);
    public RemoteWriteSpecFluent.QueueConfigNested<A> editQueueConfig();
    public RemoteWriteSpecFluent.QueueConfigNested<A> editOrNewQueueConfig();
    public RemoteWriteSpecFluent.QueueConfigNested<A> editOrNewQueueConfigLike(QueueConfig item);
    public String getRemoteTimeout();
    public A withRemoteTimeout(String remoteTimeout);
    public Boolean hasRemoteTimeout();
    public A withNewRemoteTimeout(String arg1);
    public A withNewRemoteTimeout(StringBuilder arg1);
    public A withNewRemoteTimeout(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildTlsConfig instead.
 * @return The buildable object.
 */
@Deprecated public TLSConfig getTlsConfig();
    public TLSConfig buildTlsConfig();
    public A withTlsConfig(TLSConfig tlsConfig);
    public Boolean hasTlsConfig();
    public RemoteWriteSpecFluent.TlsConfigNested<A> withNewTlsConfig();
    public RemoteWriteSpecFluent.TlsConfigNested<A> withNewTlsConfigLike(TLSConfig item);
    public RemoteWriteSpecFluent.TlsConfigNested<A> editTlsConfig();
    public RemoteWriteSpecFluent.TlsConfigNested<A> editOrNewTlsConfig();
    public RemoteWriteSpecFluent.TlsConfigNested<A> editOrNewTlsConfigLike(TLSConfig item);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(String arg1);
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(StringBuffer arg1);
    public A addToWriteRelabelConfigs(int index,RelabelConfig item);
    public A setToWriteRelabelConfigs(int index,RelabelConfig item);
    public A addToWriteRelabelConfigs(RelabelConfig... items);
    public A addAllToWriteRelabelConfigs(Collection<RelabelConfig> items);
    public A removeFromWriteRelabelConfigs(RelabelConfig... items);
    public A removeAllFromWriteRelabelConfigs(Collection<RelabelConfig> items);
    public A removeMatchingFromWriteRelabelConfigs(Predicate<RelabelConfigBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildWriteRelabelConfigs instead.
 * @return The buildable object.
 */
@Deprecated public List<RelabelConfig> getWriteRelabelConfigs();
    public List<RelabelConfig> buildWriteRelabelConfigs();
    public RelabelConfig buildWriteRelabelConfig(int index);
    public RelabelConfig buildFirstWriteRelabelConfig();
    public RelabelConfig buildLastWriteRelabelConfig();
    public RelabelConfig buildMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
    public Boolean hasMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
    public A withWriteRelabelConfigs(List<RelabelConfig> writeRelabelConfigs);
    public A withWriteRelabelConfigs(RelabelConfig... writeRelabelConfigs);
    public Boolean hasWriteRelabelConfigs();
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> addNewWriteRelabelConfig();
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> addNewWriteRelabelConfigLike(RelabelConfig item);
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> setNewWriteRelabelConfigLike(int index,RelabelConfig item);
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editWriteRelabelConfig(int index);
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editFirstWriteRelabelConfig();
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editLastWriteRelabelConfig();
    public RemoteWriteSpecFluent.WriteRelabelConfigsNested<A> editMatchingWriteRelabelConfig(Predicate<RelabelConfigBuilder> predicate);
    public interface BasicAuthNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,BasicAuthFluent<RemoteWriteSpecFluent.BasicAuthNested<N>> {

            public N and();
            public N endBasicAuth();    }


    public interface QueueConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,QueueConfigFluent<RemoteWriteSpecFluent.QueueConfigNested<N>> {

            public N and();
            public N endQueueConfig();    }


    public interface TlsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TLSConfigFluent<RemoteWriteSpecFluent.TlsConfigNested<N>> {

            public N and();
            public N endTlsConfig();    }


    public interface WriteRelabelConfigsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RelabelConfigFluent<RemoteWriteSpecFluent.WriteRelabelConfigsNested<N>> {

            public N and();
            public N endWriteRelabelConfig();    }


}
